// CustomAuthenticationProvider.java, created by Fabio Strozzi

package eu.fabiostrozzi.auth;

import net.sf.acegisecurity.Authentication;
import net.sf.acegisecurity.AuthenticationException;
import net.sf.acegisecurity.providers.AuthenticationProvider;
import net.sf.acegisecurity.providers.UsernamePasswordAuthenticationToken;
import org.alfresco.repo.security.authentication.MutableAuthenticationDao;

/**
 * Authentication provider for custom authentication.
 *
 * @author Fabio Strozzi
 */
public class CustomAuthenticationProvider implements AuthenticationProvider {
    private MutableAuthenticationDao authenticationDao;

    public void setAuthenticationDao(MutableAuthenticationDao authenticationDao) {
        this.authenticationDao = authenticationDao;
    }

    /**
     * Realizes the authentication. If authentication fails for some reason,
     * null must be returned.
     *
     * @see net.sf.acegisecurity.providers.AuthenticationProvider#authenticate(net
     *      .sf.acegisecurity.Authentication)
     */
    @Override
    public Authentication authenticate(Authentication auth) throws AuthenticationException {
        if (!supports(auth.getClass()))
            return null;
        UsernamePasswordAuthenticationToken upat = (UsernamePasswordAuthenticationToken) auth;
        String username = (String) upat.getPrincipal();

        if (authenticationDao.getAccountHasExpired(username)
                || authenticationDao.getAccountlocked(username)
                || !authenticationDao.getEnabled(username)
                || !username.equals((String) upat.getCredentials()))
            return null;
        return auth;
    }

    /*
     * @see
     * net.sf.acegisecurity.providers.AuthenticationProvider#supports(java.lang
     * .Class)
     */
    @SuppressWarnings("unchecked")
    @Override
    public boolean supports(Class auth) {
        return UsernamePasswordAuthenticationToken.class.isAssignableFrom(auth);
    }
}
